Documentation
¶
Overview ¶
Package augment implements the Augment usage provider.
Auth: `auggie account status` first, then the Usage Buttons Helper extension with the user's app.augmentcode.com browser session.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Provider ¶
type Provider struct{}
Provider fetches Augment usage data.
func (Provider) BrandColor ¶
BrandColor returns the accent color used on button faces.
Click to show internal directories.
Click to hide internal directories.